@@ -5,11 +5,12 @@ use warnings;
 
 # ABSTRACT: A processor that generates multi-paged URL lists
 
-our $VERSION = '1.111990'; # VERSION
+our $VERSION = '1.112100';    # VERSION
 
 use Moose;
 extends 'DataFlow::Proc';
 
+use Moose::Autobox;
 use namespace::autoclean;
 use Carp;
 
@@ -73,11 +74,12 @@ sub _build_p {
         my $last  = $self->last_page;
         $first = 1 + $last + $first if $first < 0;
 
-        my @result =
-          map { $self->make_page_url->( $self, $url, $_ ) } $first .. $last;
+        my $result =
+          [ $first .. $last ]
+          ->map( sub { $self->make_page_url->( $self, $url, $_ ) } );
 
         $self->clear_paged_url;
-        return [@result];
+        return $result;
     };
 }
 
@@ -85,7 +87,6 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
 __END__
 =pod
 
@@ -97,7 +98,7 @@ DataFlow::Proc::MultiPageURLGenerator - A processor that generates multi-paged U
 
 =head1 VERSION
 
-version 1.111990
+version 1.112100
 
 =head1 SEE ALSO
 
